@@ -21,7 +21,6 @@
 #define _GNU_SOURCE 1
 #define HAVE_ALLOCA_H 1
 #define HAVE_ARPA_INET_H 1
-#define HAVE_ASM_MSR_H 1
 #define HAVE_ASM_TERMBITS_H 1
 #define HAVE_CRYPT_H 1
 #define HAVE_CURSES_H 1
@@ -65,7 +64,6 @@
 #define HAVE_SYS_FILE_H 1
 /* #undef HAVE_SYS_FPU_H */
 #define HAVE_SYS_IOCTL_H 1
-#define HAVE_SYS_IPC_H 1
 /* #undef HAVE_SYS_MALLOC_H */
 #define HAVE_SYS_MMAN_H 1
 /* #undef HAVE_SYS_NDIR_H */
@@ -74,14 +72,13 @@
 #define HAVE_SYS_PRCTL_H 1
 #define HAVE_SYS_RESOURCE_H 1
 #define HAVE_SYS_SELECT_H 1
-#define HAVE_SYS_SHM_H 1
 #define HAVE_SYS_SOCKET_H 1
 /* #undef HAVE_SYS_SOCKIO_H */
 #define HAVE_SYS_UTSNAME_H 1
 #define HAVE_SYS_STAT_H 1
 /* #undef HAVE_SYS_STREAM_H */
 #define HAVE_SYS_SYSCALL_H 1
-/* #undef HAVE_SYS_TIMEB_H */
+#define HAVE_SYS_TIMEB_H 1
 #define HAVE_SYS_TIMES_H 1
 #define HAVE_SYS_TIME_H 1
 #define HAVE_SYS_TYPES_H 1
@@ -105,7 +102,6 @@
 /* Libraries */
 /* #undef HAVE_LIBWRAP */
 #define HAVE_SYSTEMD 1
-/* #undef HAVE_CRC32_VPMSUM */
 
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
@@ -123,7 +119,6 @@
 /* Functions we may want to use. */
 #define HAVE_ACCEPT4 1
 #define HAVE_ACCESS 1
-/* #undef HAVE_AIOWAIT */
 #define HAVE_ALARM 1
 #define HAVE_ALLOCA 1
 /* #undef HAVE_BFILL */
@@ -149,6 +144,7 @@
 #define HAVE_GETHOSTBYADDR_R 1
 /* #undef HAVE_GETHRTIME */
 #define HAVE_GETPAGESIZE 1
+/* #undef HAVE_GETPAGESIZES */
 #define HAVE_GETPASS 1
 /* #undef HAVE_GETPASSPHRASE */
 #define HAVE_GETPWNAM 1
@@ -161,20 +157,17 @@
 /* #undef gmtime_r */
 #define HAVE_IN_ADDR_T 1
 #define HAVE_INITGROUPS 1
-#define HAVE_LARGE_PAGE_OPTION 1
 #define HAVE_LDIV 1
 #define HAVE_LRAND48 1
 #define HAVE_LOCALTIME_R 1
 #define HAVE_LSTAT 1
 #define HAVE_MEMALIGN 1
 /* #define HAVE_MLOCK 1 see Bug#54662 */
-#define HAVE_NPTL 1
 #define HAVE_NL_LANGINFO 1
 #define HAVE_MADVISE 1
 #define HAVE_DECL_MADVISE 1
 /* #undef HAVE_DECL_MHA_MAPSIZE_VA */
 #define HAVE_MALLINFO 1
-#define HAVE_MALLINFO2 1
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
 #define HAVE_MKSTEMP 1
@@ -185,10 +178,8 @@
 #define HAVE_PERROR 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_FALLOCATE 1
-#define HAVE_LINUX_FALLOC_H 1
 #define HAVE_FALLOC_PUNCH_HOLE_AND_KEEP_SIZE 1
 #define HAVE_PREAD 1
-/* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
 /* #undef HAVE_PTHREAD_ATTR_CREATE */
 #define HAVE_PTHREAD_ATTR_GETGUARDSIZE 1
@@ -219,6 +210,7 @@
 #define HAVE_SIGACTION 1
 /* #undef HAVE_SIGTHREADMASK */
 #define HAVE_SIGWAIT 1
+#define HAVE_SIGWAITINFO 1
 #define HAVE_SLEEP 1
 #define HAVE_SNPRINTF 1
 #define HAVE_STPCPY 1
@@ -379,15 +371,12 @@
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
 #define HAVE_ERR_remove_thread_state 1
+#define HAVE_X509_check_host 1
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
-#define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
-#define HAVE_DECL_SHM_HUGETLB 1
-#define HAVE_LINUX_LARGE_PAGES 1
-#define HUGETLB_USE_PROC_MEMINFO 1
 /* #undef NO_FCNTL_NONBLOCK */
 #define NO_ALARM 1
 
@@ -497,8 +486,7 @@
 #define HAVE_CHARSET_ucs2 1
 #define HAVE_CHARSET_ujis 1
 #define HAVE_CHARSET_utf8mb4 1
-/* #undef HAVE_CHARSET_utf8mb3 */
-#define HAVE_CHARSET_utf8 1
+#define HAVE_CHARSET_utf8mb3 1
 #define HAVE_CHARSET_utf16 1
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
@@ -530,24 +518,25 @@
 #define MYSQL_DATADIR "/var/lib/mysql"
 #define DEFAULT_CHARSET_HOME "/usr"
 #define PLUGINDIR "/usr/lib/mysql/plugin"
-#define DEFAULT_SYSCONFDIR "/etc/mysql"
+#define DEFAULT_SYSCONFDIR "/etc"
 #define DEFAULT_TMPDIR P_tmpdir
 
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 3
-#define MYSQL_VERSION_PATCH 34
+#define MYSQL_VERSION_MINOR 5
+#define MYSQL_VERSION_PATCH 8
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.3.34"
+#define PACKAGE_STRING "MySQL Server 10.5.8"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.3.34"
-#define VERSION "10.3.34"
+#define PACKAGE_VERSION "10.5.8"
+#define VERSION "10.5.8"
 #define PROTOCOL_VERSION 10
+#define PCRE2_CODE_UNIT_WIDTH 8
 
 #define MALLOC_LIBRARY "system"
 
